@@ -23,10 +23,8 @@ describe 'trove::api' do
 
   let :params do
     { :keystone_password     => 'passw0rd',
-      :auth_host             => '10.0.0.10',
-      :auth_url              => 'http://10.0.0.10:5000/v2.0',
-      :auth_port             => '35357',
-      :auth_protocol         => 'https',
+      :identity_uri          => 'http://10.0.0.10:35357/',
+      :auth_uri              => 'http://10.0.0.10:5000/v2.0/',
       :keystone_tenant       => '_services_',
       :keystone_user         => 'trove',
     }
@@ -57,27 +55,25 @@ describe 'trove::api' do
         is_expected.to contain_package('trove-api').with(
           :name   => platform_params[:api_package_name],
           :ensure => 'present',
-          :notify => 'Service[trove-api]'
+          :tag    => ['openstack', 'trove-package'],
         )
       end
 
       it 'configures trove-api with default parameters' do
-        is_expected.to contain_trove_config('DEFAULT/verbose').with_value(false)
-        is_expected.to contain_trove_config('DEFAULT/debug').with_value(false)
         is_expected.to contain_trove_config('DEFAULT/bind_host').with_value('0.0.0.0')
         is_expected.to contain_trove_config('DEFAULT/bind_port').with_value('8779')
         is_expected.to contain_trove_config('DEFAULT/backlog').with_value('4096')
         is_expected.to contain_trove_config('DEFAULT/trove_api_workers').with_value('8')
-        is_expected.to contain_trove_config('DEFAULT/trove_auth_url').with_value('http://10.0.0.10:5000/v2.0')
+        is_expected.to contain_trove_config('DEFAULT/trove_auth_url').with_value('http://10.0.0.10:5000/v2.0/')
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_user').with_value('admin')
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
-        is_expected.to contain_trove_config('keystone_authtoken/auth_host').with_value('10.0.0.10')
-        is_expected.to contain_trove_config('keystone_authtoken/auth_port').with_value('35357')
-        is_expected.to contain_trove_config('keystone_authtoken/auth_protocol').with_value('https')
+        is_expected.to contain_trove_config('keystone_authtoken/auth_uri').with_value('http://10.0.0.10:5000/v2.0/')
+        is_expected.to contain_trove_config('keystone_authtoken/identity_uri').with_value('http://10.0.0.10:35357/')
         is_expected.to contain_trove_config('keystone_authtoken/admin_tenant_name').with_value('_services_')
         is_expected.to contain_trove_config('keystone_authtoken/admin_user').with_value('trove')
         is_expected.to contain_trove_config('keystone_authtoken/admin_password').with_value('passw0rd')
+        is_expected.to contain_trove_config('DEFAULT/control_exchange').with_value('trove')
         is_expected.to contain_trove_config('DEFAULT/os_region_name').with_value('RegionOne')
         is_expected.to contain_trove_config('DEFAULT/nova_compute_service_type').with_value('compute')
         is_expected.to contain_trove_config('DEFAULT/cinder_service_type').with_value('volume')
@@ -89,8 +85,56 @@ describe 'trove::api' do
         is_expected.to contain_trove_config('DEFAULT/http_put_rate').with_value('200')
         is_expected.to contain_trove_config('DEFAULT/http_delete_rate').with_value('200')
         is_expected.to contain_trove_config('DEFAULT/http_mgmt_post_rate').with_value('200')
+        is_expected.to contain_trove_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('ssl/cert_file').with_ensure('absent')
+        is_expected.to contain_trove_config('ssl/key_file').with_ensure('absent')
+        is_expected.to contain_trove_config('ssl/ca_file').with_ensure('absent')
       end
 
+      context 'with deprecated parameters' do
+        let :deprecated_params do
+          {
+            :auth_host             => '10.0.0.10',
+            :auth_url              => 'http://10.0.0.10:5000/v2.0/',
+            :auth_port             => '35357',
+            :auth_protocol         => 'http',
+          }
+        end
+
+        let :expected_params do
+          params.merge(deprecated_params)
+        end
+
+        it 'should work with deprecated parameters' do
+          is_expected.to contain_trove_config('DEFAULT/trove_auth_url').with_value(expected_params[:auth_url])
+          is_expected.to contain_trove_config('keystone_authtoken/auth_uri').with_value(expected_params[:auth_url])
+          is_expected.to contain_trove_config('keystone_authtoken/identity_uri').with_value(expected_params[:auth_protocol] + "://" + expected_params[:auth_host] + ":" + expected_params[:auth_port] + "/")
+        end
+      end
+
+      context 'with SSL enabled on API' do
+      before :each do
+        params.merge!(
+          :cert_file => 'cert',
+          :key_file  => 'key',
+          :ca_file   => 'ca',
+        )
+        end
+
+        it 'contains ssl parameters' do
+          is_expected.to contain_trove_config('ssl/cert_file').with_value('cert')
+          is_expected.to contain_trove_config('ssl/key_file').with_value('key')
+          is_expected.to contain_trove_config('ssl/ca_file').with_value('ca')
+        end
+      end
 
       context 'with overridden rate limit parameters' do
       before :each do
@@ -120,6 +164,23 @@ describe 'trove::api' do
         end
         it 'configures trove-api with RabbitMQ' do
           is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
+        end
+      end
+
+      context 'when using a single RabbitMQ server with enable ha options' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             rabbit_ha_queues      => 'true',
+             amqp_durable_queues   => 'true',
+             rabbit_host           => '10.0.0.1'}"
+        end
+        it 'configures trove-api with RabbitMQ' do
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true')
         end
       end
 
@@ -127,47 +188,12 @@ describe 'trove::api' do
         let :pre_condition do
           "class { 'trove':
              nova_proxy_admin_pass => 'verysecrete',
+             rabbit_ha_queues      => 'true',
              rabbit_hosts          => ['10.0.0.1','10.0.0.2']}"
         end
         it 'configures trove-api with RabbitMQ' do
           is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_hosts').with_value(['10.0.0.1,10.0.0.2'])
-        end
-      end
-
-      context 'when using qpid' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password'}"
-        end
-        it 'configures trove-api with qpid' do
-          is_expected.to contain_trove_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_protocol').with_value('tcp')
-        end
-      end
-
-      context 'when using qpid with SSL enabled' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password',
-             qpid_protocol         => 'ssl'}"
-        end
-        it 'configures trove-api with qpid' do
-          is_expected.to contain_trove_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_config('oslo_messaging_qpid/qpid_protocol').with_value('ssl')
+          is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
         end
       end
 
@@ -202,10 +228,10 @@ describe 'trove::api' do
 
       it do
         is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -213,25 +239,67 @@ describe 'trove::api' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => false,
-           kombu_ssl_version  => 'TLSv1'}"
+           rabbit_use_ssl     => false}"
       end
 
       it do
         is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
       end
     end
 
+    context 'with transport_url entries' do
+      let :pre_condition do
+        "class { 'trove':
+           nova_proxy_admin_pass => 'verysecrete',
+           default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+           notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673' }"
+      end
+
+      it do
+        is_expected.to contain_trove_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+        is_expected.to contain_trove_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+      end
+    end
+
+    context 'with amqp rpc' do
+      let :pre_condition do
+        "class { 'trove' :
+           nova_proxy_admin_pass => 'verysecrete',
+           rpc_backend => 'amqp' }"
+      end
+
+      it do
+        is_expected.to contain_trove_config('DEFAULT/rpc_backend').with_value('amqp')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
+      end
+    end
   end
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily       => 'Debian',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'Debian',
+        :processorcount => 8,
+      })
     end
 
     let :platform_params do
@@ -244,8 +312,10 @@ describe 'trove::api' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily       => 'RedHat',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'RedHat',
+        :processorcount => 8,
+      })
     end
 
     let :platform_params do
